<?xml version="1.0" encoding="utf-8"?>

<!-- XSLT transformation sheet with hamburger menu -->

<!-- This software is Open Source. Use it under the GNU Public License --> 
<!-- Please do read file COPYING.txt -->

<!-- Author and copyright 2021-2024 Dr. Thomas Redelberger, redetho@gmx.de -->

<!-- $Id$ -->

<xsl:stylesheet	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
	<xsl:output method="xml" encoding="utf-8" omit-xml-declaration="yes"/>


	<!-- ****************** Parameters for this stylesheet ***************** -->

	<xsl:param    name="mySrcDoc"     select="'body.htm'"/>		<!-- default source file name -->
	<xsl:param    name="myISODT"      select="'20021118120000'"/>		<!-- default update date/time -->
	<xsl:param    name="myISOTodayDT" select="'20240101120000'"/>		<!-- default calendar date/time -->

	<xsl:param    name="myDstDoc"     select="'index.htm'"/>	<!-- default destination file name -->
	<xsl:param    name="myCSSDoc"     select="'site.css'"/>		<!-- default CSS file name -->


	<!-- ******************* Constants for this stylesheet ***************** -->

	<xsl:variable name="myYear"       select="substring($myISODT,1,4)"/>	<!-- just for convenience -->
	<xsl:variable name="myMonth"      select="substring($myISODT,5,2)"/>
	<xsl:variable name="myDay"        select="substring($myISODT,7,2)"/>
	<xsl:variable name="myTodayYear"  select="substring($myISOTodayDT,1,4)"/>


	<!-- site specific stuff following -->
	<!-- Teutsch
	<xsl:variable name="myDT"         select="concat($myDay, '.', $myMonth, '.', $myYear)"/>
	-->
	<!-- ISO -->
	<xsl:variable name="myDT"         select="concat($myYear, '-', $myMonth, '-', $myDay)"/>
	<!-- -->
	<!-- US
	<xsl:variable name="myDT"         select="concat($myMonth, '/', $myDay, '/', $myYear)"/>
	-->


<!-- UTF-8/Unicode characters as navigation symbols
	<xsl:variable name="htHmbrgrSymVar">
		<span class="htHmbrgrSym">≡</span>
	</xsl:variable>

	<xsl:variable name="htClsrSymVar">
		<span class="htHmbrgrSym">X</span>
	</xsl:variable>

	<xsl:variable name="htHomeSymVar">
		<span class="htLeftNavSym">▲</span>
	</xsl:variable>

	<xsl:variable name="htHngMiSymVar">
		<span class="htLeftNavSym">▼</span>
	</xsl:variable>

	<xsl:variable name="htHngPlSymVar">
		<span class="htLeftNavSym">►</span>
	</xsl:variable>

	<xsl:variable name="htHngSymVar">
		<span class="htLeftNavSym"> </span>
	</xsl:variable>
-->

<!-- SVG graphics as navigation symbols -->
	<xsl:variable name="htHmbrgrSymVar">
		<img src="{/htWeb2/htUpDir}/htHmbrgr.svg" id="htHmbrgr" alt="Menu"/>
	</xsl:variable>

	<xsl:variable name="htClsrSymVar">
		<img src="{/htWeb2/htUpDir}/htClsr.svg" id="htClsrIcn" alt="Close menu"/>
	</xsl:variable>

	<xsl:variable name="htHomeSymVar">
		<img src="{/htWeb2/htUpDir}/htHome.svg" class="htNvGr" alt="Home" />
	</xsl:variable>

	<xsl:variable name="htHngMiSymVar">
		<img src="{/htWeb2/htUpDir}/htHngMi.svg" class="htNvGr" alt="Collapse" />
	</xsl:variable>

	<xsl:variable name="htHngPlSymVar">
		<img src="{/htWeb2/htUpDir}/htHngPl.svg" class="htNvGr" alt="Expand" />
	</xsl:variable>

	<xsl:variable name="htHngSymVar">
		<img src="{/htWeb2/htUpDir}/htHng.svg" class="htNvGr" alt="" />
	</xsl:variable>
<!-- -->



	<!-- ******************** Auxiliary Named Templates ******************** -->



	<!-- ******************************************************************* -->

	<xsl:template match="/htWeb2">
		<!-- Do DOCTYPE the hard way -->
		<xsl:text disable-output-escaping='yes'>&lt;!DOCTYPE html&gt;</xsl:text>

		<!-- copy over language attribute from html element of body.htm -->
		<html lang="{document(concat(htHomeDir, '/', htDownDir, '/', $mySrcDoc))/html/@lang}">
			<head>
				<meta charset="UTF-8"/>
				<!-- enable search engines -->
				<meta name="robots" content="index,follow"/>
				<!-- support mobile devices -->
				<meta name="viewport" content="width=device-width, initial-scale=1.0"/>

				<!-- copy over other meta stuff from body.htm, except mine and charset and viewport -->
				<!-- I might have viewport in body.htm in the future, hence this avoids duplification -->
				<xsl:copy-of select="document(concat(htHomeDir, '/', htDownDir, '/', $mySrcDoc))/html/head/meta[not( starts-with(@name, 'ht') or @charset or @name='viewport')]"/>

				<!-- use one global CSS style sheet -->
				<link rel="stylesheet" type="text/css" href="{htUpDir}/{$myCSSDoc}"/>

				<!-- copy over title from body.htm -->
				<xsl:copy-of select="document(concat(htHomeDir, '/', htDownDir, '/', $mySrcDoc))/html/head/title"/>
			</head>


			<body>

				<!-- Top Banner -->
				<div id="htHeader">
					<a href="#htLeftWrapper" id="htHmbrgrLnk">
						<xsl:copy-of select="$htHmbrgrSymVar"/>
					</a>
					<img src="{htUpDir}/redetho-logo1.svg" id="htLogo" alt="redetho logo"/>
				</div>

				<!-- Main Content -->
				<div id="htMainWrapper">
					<xsl:copy-of select="document(concat(htHomeDir, '/', htDownDir, '/', $mySrcDoc))/html/body/node()"/>

					<!-- Footer -->
					<hr id="htFootSep"/>
					<p id="htFooter">Last change: <xsl:value-of select="$myDT"/><br/>© 2002-<xsl:value-of select="$myTodayYear"/> Dr. Thomas Redelberger redetho(at)gmx.de</p>
				</div>


				<!-- Navigation -->
				<div id="htLeftWrapper">
					<a href="./{$myDstDoc}" id="htHmbrgrLnk">
						<xsl:copy-of select="$htClsrSymVar"/>
					</a>
					<ul class="htLeftNavUl0">
						<xsl:apply-templates select="htNode"/>
					</ul>	
				</div>


			</body>
		</html>
	</xsl:template>		<!-- end match root -->



	<!-- ******************************************************************* -->

	<xsl:template match="htNode">	<!-- For each Node  -->

		<xsl:variable name="TabNameVar">
			<xsl:choose>	<!-- the current TabName gets emphasized -->
				<xsl:when test="@isCurrent='y'">
					<strong><em><xsl:value-of select="TabName"/></em></strong>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="TabName"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>

		<li class="htLeftNavLi">

			<!-- appropriate path graphics -->
			<xsl:choose>	<!-- /home/ gets special graphics -->
				<xsl:when test="@levelNo = '1'">
					<a href="{TgtURI}/{$myDstDoc}" class="htLeftNavA">
						<xsl:copy-of select="$htHomeSymVar"/>
						<xsl:copy-of select="$TabNameVar"/>
					</a>
				</xsl:when>

				<xsl:otherwise>
					<xsl:choose>	<!-- different graphics -->
						<xsl:when test="@hasChilds = 'y' and htNode">
							<a href="../{$myDstDoc}" class="htLeftNavA">
								<xsl:copy-of select="$htHngMiSymVar"/>
								<xsl:copy-of select="$TabNameVar"/>
							</a>
						</xsl:when>

						<xsl:when test="@hasChilds = 'y' and not(htNode)">
							<a href="{TgtURI}/{$myDstDoc}" class="htLeftNavA">
								<xsl:copy-of select="$htHngPlSymVar"/>
								<xsl:copy-of select="$TabNameVar"/>
							</a>
						</xsl:when>

						<xsl:when test="not(@hasChilds = 'y')">
							<a href="{TgtURI}/{$myDstDoc}" class="htLeftNavA">
								<xsl:copy-of select="$htHngSymVar"/>
								<xsl:copy-of select="$TabNameVar"/>
							</a>
						</xsl:when>
					</xsl:choose>	<!-- different graphics -->
				</xsl:otherwise>
			</xsl:choose>	<!-- /home/ -->



			<!--recursively go down to next node(s) -->
			<xsl:if test="htNode">				<!-- avoid trailing empty list -->
				<ul class="htLeftNavUlN">
					<xsl:apply-templates select="htNode"/>
				</ul>	
			</xsl:if>

		</li>

	</xsl:template>		<!-- For each Node  -->



</xsl:stylesheet>

<!-- ************************* End of trWSite.xsl ************************** -->
