<?xml version="1.0" encoding="utf-8"?>

<!-- style sheet for the trgensit documentation example site -->

<!-- This software is Open Source. Use it under the GNU Public License --> 
<!-- Please do read file COPYING.txt -->

<!-- Author and copyright 2021-2024 Dr. Thomas Redelberger, redetho@gmx.de -->

<!-- $Id$ -->
 
<xsl:stylesheet	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
	<xsl:output method="xml" encoding="utf-8" omit-xml-declaration="yes"/>


	<!-- ****************** Parameters for this stylesheet ***************** -->

	<xsl:param    name="mySrcDoc"     select="'body.htm'"/>		<!-- default source file name -->
	<xsl:param    name="myISODT"      select="'20021118120000'"/>		<!-- default update date/time -->
	<xsl:param    name="myISOTodayDT" select="'20240101120000'"/>		<!-- default calendar date/time -->

	<xsl:param    name="myDstDoc"     select="'index.htm'"/>	<!-- default destination file name -->
	<xsl:param    name="myCSSDoc"     select="'site.css'"/>		<!-- default CSS file name -->


	<!-- ******************* Constants for this stylesheet ***************** -->

	<xsl:variable name="myYear"       select="substring($myISODT,1,4)"/>	<!-- just for convenience -->
	<xsl:variable name="myMonth"      select="substring($myISODT,5,2)"/>
	<xsl:variable name="myDay"        select="substring($myISODT,7,2)"/>
	<xsl:variable name="myTodayYear"  select="substring($myISOTodayDT,1,4)"/>


	<!-- site specific stuff following -->
	<!-- Teutsch
	<xsl:variable name="myDT"         select="concat($myDay, '.', $myMonth, '.', $myYear)"/>
	-->
	<!-- ISO -->
	<xsl:variable name="myDT"         select="concat($myYear, '-', $myMonth, '-', $myDay)"/>
	<!-- -->
	<!-- US
	<xsl:variable name="myDT"         select="concat($myMonth, '/', $myDay, '/', $myYear)"/>
	-->



	<!-- ******************** Auxiliary Named Templates ******************** -->


	<!-- ******************************************************************* -->
	<!-- kill the default text and attribute templates -->
	<!-- omitting the mode does /not/ catch all modes -->
	<xsl:template match="text()|@*" mode="myBreadCrumb" />
	<xsl:template match="text()|@*" mode="myChilds" />


	<!-- ******************************************************************* -->

	<xsl:template match="/htWeb2">
		<!-- Do DOCTYPE the hard way -->
		<xsl:text disable-output-escaping='yes'>&lt;!DOCTYPE html&gt;</xsl:text>

		<!-- copy over language attribute from html element of body.htm -->
		<html lang="{document(concat(htHomeDir, '/', htDownDir, '/', $mySrcDoc))/html/@lang}">
			<head>
				<meta charset="UTF-8"/>
				<!-- enable search engines -->
				<meta name="robots" content="index,follow"/>
				<!-- support mobile devices -->
				<meta name="viewport" content="width=device-width, initial-scale=1.0"/>

				<!-- copy over other meta stuff from body.htm, except mine and charset and viewport -->
				<!-- I might have viewport in body.htm in the future, hence this avoids duplification -->
				<xsl:copy-of select="document(concat(htHomeDir, '/', htDownDir, '/', $mySrcDoc))/html/head/meta[not( starts-with(@name, 'ht') or @charset or @name='viewport')]"/>

				<!-- use one global CSS style sheet -->
				<link rel="stylesheet" type="text/css" href="{htUpDir}/{$myCSSDoc}"/>

				<!-- copy over title from body.htm -->
				<xsl:copy-of select="document(concat(htHomeDir, '/', htDownDir, '/', $mySrcDoc))/html/head/title"/>			</head>

			<body>

				<!-- Top Banner -->
				<div id="htHeader">
					<img src="{htUpDir}/redetho-logo1.svg" id="htLogo" alt="redetho logo"/>
				</div>


				<!-- Navigation -->
				<xsl:if test="htLevelNo > 1">	<!-- show bread crumb only for nodes below home -->
					<div id="htBreadCrumb">
						<xsl:apply-templates select="//htNode[@inTree='y']" mode="myBreadCrumb"/>
					</div>
				</xsl:if>

				<div id="htNavWrapper">
					<ul class="htNavUl">
						<xsl:apply-templates select="//htNode[/htWeb2/htLevelNo +1 = @levelNo]" mode="myChilds"/>
					</ul>	
				</div>
				

				<!-- Main Content -->
				<div id="htMainWrapper">
					<xsl:copy-of select="document(concat(htHomeDir, '/', htDownDir, '/', $mySrcDoc))/html/body/node()"/>

					<!-- Footer -->
					<hr id="htFootSep"/>
					<p id="htFooter">Last change: <xsl:value-of select="$myDT"/><br/>© 2002-<xsl:value-of select="$myTodayYear"/> Dr. Thomas Redelberger redetho(at)gmx.de</p>
				</div>

			</body>
		</html>
	</xsl:template>		<!-- end match root -->




	<!-- ************************ Bread Crumb ****************************** -->

	<xsl:template match="htNode" mode="myBreadCrumb">
		<!-- the greater sign only in between, not in front of home -->
		<xsl:if test="@levelNo &gt; 1"><xsl:text> &gt; </xsl:text></xsl:if>

		<xsl:choose>
			<xsl:when test="@isCurrent='y'">	<!-- if this is the current one, just text -->
				<xsl:value-of select="TabName"/>
			</xsl:when>
			<xsl:otherwise>
				<a href="{TgtURI}/{$myDstDoc}"><xsl:value-of select="TabName"/></a>
			</xsl:otherwise>
		</xsl:choose>

	</xsl:template>


	<!-- *********************** Childs ************************************ -->

	<xsl:template match="htNode" mode="myChilds">
		<li class="htNavLi">
			<a href="{TgtURI}/{$myDstDoc}"><xsl:value-of select="TabName"/></a>
		</li>
	</xsl:template>



</xsl:stylesheet>

<!-- ************************* End of trWSite.xsl ************************** -->
