# File trwsmap.py
# Part of the trgensit package.
#
# * Functionality
#
# Recursively processes the /parent/ of the current working directory and all its
# sub-directories and generates body.htm in the current working directory with a
# tree of all index.htm.
# Must have files trWNav.xml in /each/ folder.
# Hence trwnvall must have been run on the complete site to generate all
# trWNav.xml files.
# Finally trwupds must be run in the current working directory to generate or update index.htm
# in that folder.
#
#
# Copyright 2019-2020 Dr. Thomas Redelberger, redetho@gmx.de
# This code is open source according to GPL2.
# See file COPYING.TXT
#
# * Pre-requisites
#
# - Nothing beyond python
#
#
# $Id: trwsmap.py 1.1 2020/03/20 09:11:43 redetho Exp redetho $


import pathlib
import xml.etree.ElementTree as ET

import trwlib




def putNode(thisDirOb, parentElm):
    "This function generates one link and then recursively for all childs"
    
    fileOb = thisDirOb.joinpath(trwlib.navNamStr)
    try:
        treeOb = ET.parse(str(fileOb))    # open accepts pathlib object only >= 3.6
    except Exception as e:
        # e.errno is avail. for file related erors, but not for parse related errors
        #print('{}: Error: File >>{}<< cannot be opened or parsed'.format(__file__, thisDirOb.joinpath(trwlib.navNamStr)) )
        #quit(trwlib.myErrNo)   # no point to continue
        print('{}: Warning: File >>{}<< cannot be opened or parsed'.format(__file__, thisDirOb.joinpath(trwlib.navNamStr)) )
        return

    tabElm = treeOb.find("htTabName")
    tabStr = tabElm.text if tabElm is not None else '???'

    tgtElm = treeOb.find("htDownDir")
    tgtStr = tgtElm.text if tgtElm is not None else '.'   # *** should quit if missing?

    ignoreElm = treeOb.find("htIgnore")
    ignoreBl = (ignoreElm.text in ('y', 'Y', 'yes', 'Yes')) if ignoreElm is not None else False

    # *** I am not using htOrder here yet.
    # order defaults to name of directory. thisDirOb.parts[-1] should be the same as htWeb2/htDir
    orderElm =  treeOb.find("htOrder")
    orderStr = orderElm.text if orderElm is not None else thisDirOb.parts[-1]

    # if a node is ignored, its childs are also, even if they are not marked
    
    if not ignoreBl:
        dlElm = ET.SubElement(parentElm, 'dl')
        ddElm = ET.SubElement(dlElm, 'dd')
        aElm = ET.SubElement(ddElm, 'a', {'href':'../{}/{}'.format(tgtStr, trwlib.dstNamStr)})
        aElm.text = tabStr
        
        for childDirOb in thisDirOb.iterdir():
            if childDirOb.is_dir():
                putNode(childDirOb, dlElm)

    


def putWork(workDirOb):
    "This function generates the body.htm file for the sitemap page"

    docElm = ET.Element('html')

    headElm = ET.SubElement(docElm, 'head')
    ET.SubElement(headElm, 'title').text = 'Site Map'
    ET.SubElement(headElm, 'meta', {'name':'htTab', 'content':'Site Map'})
    ET.SubElement(headElm, 'meta', {'name':'htOrder', 'content':'95'})

    bodyElm = ET.SubElement(docElm, 'body')
    ET.SubElement(bodyElm, 'h1').text = 'Site Map'

    # recursively build up links to all leaves in site
    putNode(workDirOb, bodyElm)
    
    #ET.dump(docElm)
    # write the result body.htm file as XML
    try:
        ET.ElementTree(docElm).write(str(workDirOb.joinpath(outDirStr, trwlib.srcNamStr)), encoding="UTF-8", xml_declaration=True)
    except Exception as e:
        print('{}: File >>{}<< cannot be written'.format(__file__, workDirOb.joinpath(outDirStr, trwlib.srcNamStr)) )
        quit(trwlib.myErrNo)   # no point to continue



# I need to start from the home directory
# *** assumption: site map is the direct child of home

outDirStr = pathlib.Path.cwd().parts[-1]
putWork(pathlib.Path.cwd().parent)





######################## end of trwsmap.py ###########################
