# File trwupds.py
# Part of the trgensit package.
#
# * Functionality
#
# Generates the index.htm file.
# The files body.htm and and trWNav.xml are expected in the source directory
#
#
# Copyright 2019-2020 Dr. Thomas Redelberger, redetho@gmx.de
# This code is open source according to GPL2.
# See file COPYING.TXT
#
# * Pre-requisites
#
# - xsltproc must be in the path.
#
#
# $Id: trwupds.py 1.1 2020/03/20 09:11:43 redetho Exp redetho $


import datetime
import os
import pathlib
import xml.etree.ElementTree as ET

import trwlib



def getRootRelPath(thisDirOb, navNamStr):
    "This function gets the relative path of the root folder as a Posix string"
    "The root folder is the directory which contains the 'home' directory"

    try:
        treeOb = ET.parse(str(thisDirOb.joinpath(navNamStr))) # open accepts pathlib object only >= 3.6
    except Exception as e:
        # e.errno is avail. for file related erors, but not for parse related errors
        print('{}: Error: File >>{}<< cannot be opened or parsed'.format(__file__, thisDirOb.joinpath(navNamStr)) )
        quit(trwlib.myErrNo)	# no point to continue

    relPathElm = treeOb.find("htUpDir")	        # relative path to the home directory
    if relPathElm is not None: return relPathElm.text + '/..'   # one dir. higher for root
    else: return ''
    
    

def updateIndex(thisDirOb, srcNamStr=trwlib.srcNamStr, dstNamStr=trwlib.dstNamStr):
    "This function generates the index.htm file in the directory thisDirOb"

    # extract the path to the style sheet from file navNamStr
    xslFileRelPathStr = getRootRelPath(thisDirOb, trwlib.navNamStr) + "/" + trwlib.xslNamStr

    srcFileOb = thisDirOb.joinpath(srcNamStr)
    try:
        dtFlt = srcFileOb.stat().st_mtime
    except Exception as e:
        print('{}: Error {}: File >>{}<< cannot be accessed'.format(__file__, e.errno, thisDirOb.joinpath(srcNamStr)) )
        quit(trwlib.myErrNo)
    ISODateStr = datetime.datetime.fromtimestamp(dtFlt).strftime('%Y%m%d%H%M%S')
    ISOTodayStr = datetime.datetime.today().strftime('%Y%m%d%H%M%S')
    #print(ISODateStr)

    if not thisDirOb.joinpath(xslFileRelPathStr).exists():
        print('{}: Error: File >>{}<< does not exist'.format(__file__, thisDirOb.joinpath(xslFileRelPathStr)) )
        quit(trwlib.myErrNo)

    # do the XSLT transformation to generate the destination index.htm file
    # as the xsltproc command line uses relative paths, I need to set the cwd first
    os.system("cd " + str(thisDirOb) + " && xsltproc "
              "--stringparam myISODT " + ISODateStr + " "
              "--stringparam myISOTodayDT " + ISOTodayStr + " "
              "--stringparam mySrcDoc " + srcNamStr + " "
              "--stringparam myDstDoc " + dstNamStr + " "
              "--novalid --nonet "
              "-o " + dstNamStr + " " + xslFileRelPathStr + " " + trwlib.navNamStr)





############### main #################
# When used as a script, pass current working directory as argument

if __name__ == "__main__":
    # execute only if run as a script
    updateIndex(pathlib.Path.cwd())


######################## end of trwupds.py ###########################
